@@ -5,7 +5,7 @@
 # Copyright (c) 2018 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-use strict;
+use strict; die $_ if ($_=`$^X -cw @{[__FILE__]} 2>&1`) !~ /^.+ syntax OK$/;
 use FindBin;
 use lib "$FindBin::Bin/../lib";
 
@@ -13,13 +13,13 @@ my @data = ();
 open(JACODE4E,"$FindBin::Bin/../lib/jacode4e.pl") || die;
 while (<JACODE4E>) {
     if (/^__DATA__$/) {
-        chomp(@data = <JACODE4E>);
+        chomp(@data = grep( ! /^#/, <JACODE4E>));
         last;
     }
 }
 close(JACODE4E);
 
-my @encoding = qw( cp932x cp932 sjis2004 cp00930 keis78 keis83 keis90 jef jipsj jipse unicode utf8 utf8jp );
+my @encoding = qw( cp932x cp932 sjis2004 cp00930 keis78 keis83 keis90 jef jipsj jipse letsj unicode utf8 utf8jp );
 my @io_encoding = (grep( ! /^unicode$/, @encoding), 'jef9p');
 my %geta = (
     'cp932x'   => '81AC',
@@ -33,6 +33,7 @@ my %geta = (
     'jef9p'    => 'A2AE',
     'jipsj'    => '222E',
     'jipse'    => '7F4B',
+    'letsj'    => 'A2AE',
     'utf8'     => 'E38093',
     'utf8jp'   => 'F3B085AB',
 );
